import { html, repeat, ref, when, slotted } from '@microsoft/fast-element';
import { whitespaceFilter } from '@microsoft/fast-foundation';
const ARROW_SVG_PATH = 'M11.85.65c.2.2.2.5 0 .7L6.4 6.84a.55.55 0 01-.78 0L.14 1.35a.5.5 0 11.71-.7L6 5.8 11.15.65c.2-.2.5-.2.7 0z';
export const getPrefixedMultiselect = (prefix = 'foundation') => html `
  <label
    part="label"
    for="control"
    class="${(x) => x.defaultSlottedNodes && x.defaultSlottedNodes.length ? 'label' : 'label label-hidden'}"
  >
    <slot
      name="label"
      ${slotted({
    property: 'defaultSlottedNodes',
    filter: whitespaceFilter,
})}
    ></slot>
  </label>
  <div class="root" part="root">
    <div class="control" part="control">
      <svg
        viewBox="0 0 12 7"
        ${ref('arrowIcon')}
        @click=${(x) => x.toggle()}
        id="arrow-icon"
        width="16px"
        fill="white"
        xmlns="http://www.w3.org/2000/svg"
      >
        <path d="${ARROW_SVG_PATH}" />
      </svg>
      <input
        part="input"
        readonly
        type="text"
        id="display-field"
        part="display-field"
        :value="${(x) => x.getDisplayValue}"
        @click=${(x) => x.toggle()}
      />
    </div>
    <div ${ref('optionsElement')} class="options">
      ${when((x) => x.search, html `
          <${prefix}-text-field
            id="filter-search"
            part="filter-search"
            placeholder="${(x) => x.getPlaceholder}"
            @input=${(x, c) => x.setFilter(c.event)}
            @change=${(x, c) => x.changeHandler(c.event)}
          ></${prefix}-text-field>
        `)}
      <div class="checkbox-container">
        ${when((x) => x.all, html `
            <${prefix}-checkbox
              @click=${(x) => x.selectCheckboxAll()}
              @change=${(x, c) => x.changeHandler(c.event)}
              ?current-checked="${(x) => x.isAllSelected}"
            >
              All ${(x) => x.name}
            </${prefix}-checkbox>
          `)}
        ${repeat((x) => x.filteredAvailableOptions, html `
            <${prefix}-checkbox
              @click=${(x, c) => c.parent.selectCheckboxOne(x)}
              @change=${(x, c) => c.parent.changeHandler(c.event)}
              ?current-checked="${(x, c) => c.parent.isOptionSelected(x)}"
            >
              ${(x, ctx) => ctx.parent.getItemLabel(x)}
            </${prefix}-checkbox>
          `)}
      </div>
    </div>
  </div>
`;
export const multiselectTemplate = html `
  ${getPrefixedMultiselect()}
`;
